@@ -1,7 +1,7 @@
 package HTML::Template::Compiled;
 # doesn't work with make tardist
 #our $VERSION = ($version_pod =~ m/^\$VERSION = "(\d+(?:\.\d+)+)"/m) ? $1 : "0.01";
-our $VERSION = "1.000_004";
+our $VERSION = "1.000_005";
 use Data::Dumper;
 use Scalar::Util;
 BEGIN {
@@ -363,6 +363,9 @@ sub from_cache {
             ? $self->get_filename
             : $self->createFilename( $self->get_path, \$self->get_filename );
         my $dir     = $self->get_cache_dir;
+        if (defined $dir and not -d $dir) {
+            croak "Cachedir '$dir' does not exist";
+        }
         $t = $self->from_file_cache($dir, $file);
         if ($t) {
             $t->set_args($args);
@@ -561,6 +564,9 @@ sub add_file_cache {
     my ( $self, $source, %times ) = @_;
     $self->lock;
     my $cache    = $self->get_cache_dir;
+    if (defined $cache and not -d $cache) {
+        croak "Cachedir '$cache' does not exist";
+    }
     my $plfile   = $self->escape_filename( $self->get_file );
     my $filename = $self->get_filename;
     my $lmtime   = localtime $times{mtime};
@@ -568,6 +574,8 @@ sub add_file_cache {
     my $cachefile = "$cache/$plfile";
     D && $self->log("add_file_cache() $cachefile");
     {
+        require Storable;
+        require B::Deparse;
         local $Storable::Deparse = 1;
         my $clone = $self->clone;
         $clone->prepare_for_cache;
@@ -610,7 +618,8 @@ sub include_file {
     my $r;
     my $t;
     {
-        #require Storable;
+        require Storable;
+        require B::Deparse;
         local $Storable::Eval = 1;
         my $cache;
         eval {
@@ -700,13 +709,7 @@ sub init_cache {
     my ($self, $args) = @_;
     my $cachedir = $args->{file_cache_dir};
     if ($args->{file_cache}) {
-        unless (require_storable()) {
-            croak "Storable and B::Deparse needed for file cache";
-        }
         $self->set_cache_dir($cachedir) if $args->{file_cache};
-        if (defined $cachedir and not -d $cachedir) {
-            croak "Cachedir '$cachedir' does not exist";
-        }
     }
     $self->set_cache( exists $args->{cache} ? $args->{cache} : 1 );
 }
@@ -1539,7 +1542,7 @@ HTML::Template::Compiled - Template System Compiles HTML::Template files to Perl
 
 =head1 VERSION
 
-$VERSION = "1.000_004"
+$VERSION = "1.000_005"
 
 =cut
 
@@ -2727,7 +2730,7 @@ Default: 0
   );
 
 If any runtime errors occur, line information will output the template
-filename and line instead of eval and the geberated perl code line
+filename and line (instead of "eval" and the generated perl code line)
 
 =item warnings (fixed) (since 1.000_004)
 
